import i18n from 'i18next';
import LanguageDetector from 'i18next-browser-languagedetector';
import { initReactI18next } from 'react-i18next';
import enTranslations from './locales/en/translation.json';
import enDocExplorer from './locales/en/DocExplorer.json';
import enToolbar from './locales/en/Toolbar.json';
import enEditor from './locales/en/Editor.json';
import enErrors from './locales/en/Errors.json';
import ruTranslations from './locales/ru/translation.json';
import ruDocExplorer from './locales/ru/DocExplorer.json';
import ruToolbar from './locales/ru/Toolbar.json';
import ruEditor from './locales/ru/Editor.json';
import ruErrors from './locales/ru/Errors.json';
var resources = {
    en: {
        translations: enTranslations,
        DocExplorer: enDocExplorer,
        Toolbar: enToolbar,
        Editor: enEditor,
        Errors: enErrors,
    },
    ru: {
        translations: ruTranslations,
        DocExplorer: ruDocExplorer,
        Toolbar: ruToolbar,
        Editor: ruEditor,
        Errors: ruErrors,
    },
};
i18n
    .use(LanguageDetector)
    .use(initReactI18next)
    .init({
    detection: {
        order: [
            'querystring',
            'localStorage',
            'navigator',
            'htmlTag',
            'path',
            'subdomain',
        ],
        lookupQuerystring: 'lng',
        lookupCookie: 'i18next',
        lookupLocalStorage: 'i18nextLng',
        lookupFromPathIndex: 0,
        lookupFromSubdomainIndex: 0,
        caches: ['localStorage'],
        excludeCacheFor: ['cimode'],
        cookieMinutes: 10,
        cookieDomain: window.location.hostname,
        htmlTag: document.documentElement,
    },
    resources: resources,
    fallbackLng: {
        'en-US': ['en'],
        default: ['en'],
    },
    whitelist: ['en', 'ru'],
    defaultNS: 'translation',
    load: 'currentOnly',
    preload: ['en', 'ru'],
    keySeparator: '.',
    nsSeparator: ':',
    interpolation: {
        escapeValue: false,
    },
    react: {
        wait: true,
    },
});
export default i18n;
//# sourceMappingURL=i18n.js.map